@@ -42,7 +42,7 @@ setPentahoEnv
 # **************************************************
 
 LIBPATH="NONE"
-STARTUP="$BASEDIR/launcher/pentaho-application-launcher-5.4.0.0-128.jar"
+STARTUP="$BASEDIR/launcher/pentaho-application-launcher-6.1.0.1-196.jar"
 
 if [ -z "$IS_YARN" ]; then
 	# Go to directory where spoon.sh located
@@ -190,15 +190,15 @@ export LIBPATH
 
 # ******************************************************************
 # ** Set java runtime options                                     **
-# ** Change 512m to higher values in case you run out of memory   **
+# ** Change 2048m to higher values in case you run out of memory  **
 # ** or set the PENTAHO_DI_JAVA_OPTIONS environment variable      **
 # ******************************************************************
 
 if [ -z "$PENTAHO_DI_JAVA_OPTIONS" ]; then
-    PENTAHO_DI_JAVA_OPTIONS="-Xmx512m -XX:MaxPermSize=256m"
+    PENTAHO_DI_JAVA_OPTIONS="-Xms1024m -Xmx2048m -XX:MaxPermSize=256m"
 fi
 
-OPT="$OPT $PENTAHO_DI_JAVA_OPTIONS -Djava.library.path=$LIBPATH -DKETTLE_HOME=$KETTLE_HOME -DKETTLE_REPOSITORY=$KETTLE_REPOSITORY -DKETTLE_USER=$KETTLE_USER -DKETTLE_PASSWORD=$KETTLE_PASSWORD -DKETTLE_PLUGIN_PACKAGES=$KETTLE_PLUGIN_PACKAGES -DKETTLE_LOG_SIZE_LIMIT=$KETTLE_LOG_SIZE_LIMIT -DKETTLE_JNDI_ROOT=$KETTLE_JNDI_ROOT"
+OPT="$OPT $PENTAHO_DI_JAVA_OPTIONS -Dhttps.protocols=TLSv1,TLSv1.1,TLSv1.2 -Djava.library.path=$LIBPATH -DKETTLE_HOME=$KETTLE_HOME -DKETTLE_REPOSITORY=$KETTLE_REPOSITORY -DKETTLE_USER=$KETTLE_USER -DKETTLE_PASSWORD=$KETTLE_PASSWORD -DKETTLE_PLUGIN_PACKAGES=$KETTLE_PLUGIN_PACKAGES -DKETTLE_LOG_SIZE_LIMIT=$KETTLE_LOG_SIZE_LIMIT -DKETTLE_JNDI_ROOT=$KETTLE_JNDI_ROOT"
 
 # optional line for attaching a debugger
 # OPT="$OPT -Xdebug -Xnoagent -Djava.compiler=NONE -Xrunjdwp:transport=dt_socket,server=y,suspend=n,address=5005"
@@ -206,7 +206,20 @@ OPT="$OPT $PENTAHO_DI_JAVA_OPTIONS -Djava.library.path=$LIBPATH -DKETTLE_HOME=$K
 # ***************
 # ** Run...    **
 # ***************
-"$_PENTAHO_JAVA" $OPT -jar "$STARTUP" -lib $LIBPATH "${1+$@}"
+inputtoexitstatus() {
+  read exitstatus
+  return $exitstatus
+}
+
+OS=`uname -s | tr '[:upper:]' '[:lower:]'`
+if [ $OS = "linux" ]; then
+    (((("$_PENTAHO_JAVA" $OPT -jar "$STARTUP" -lib $LIBPATH "${1+$@}"  2>&1; echo $? >&3 ) | grep -viE "Gtk-WARNING|GLib-GObject|GLib-CRITICAL|^$" >&4 ) 3>&1)| inputtoexitstatus ) 4>&1
+else
+    "$_PENTAHO_JAVA" $OPT -jar "$STARTUP" -lib $LIBPATH "${1+$@}"
+fi
+EXIT_CODE=$?
 
 # return to the catalog from which spoon.sh has been started
-cd $INITIALDIR
\ No newline at end of file
+cd $INITIALDIR
+
+exit $EXIT_CODE
